@@ -16,7 +16,8 @@ NULL
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dsConnect(DSOpal::Opal(), "server1", "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1", 
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' con
 #' dsDisconnect(con)
 #' }
@@ -35,11 +36,13 @@ setClass("DSConnection", representation(name = "character"), contains = c("DSObj
 #'
 #' @param conn An object that inherits from \code{\link{DSConnection-class}}.
 #'
+#' @return A character vector of table names.
+#' 
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsListTables(con)
 #' dsDisconnect(con)
 #' }
@@ -63,8 +66,8 @@ setGeneric("dsListTables",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsHasTable(con, "test.CNSIM")
 #' dsDisconnect(con)
 #' }
@@ -87,8 +90,8 @@ setGeneric("dsHasTable",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsListResources(con)
 #' dsDisconnect(con)
 #' }
@@ -112,8 +115,8 @@ setGeneric("dsListResources",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsHasResource(con, "test.CNSIM")
 #' dsDisconnect(con)
 #' }
@@ -148,8 +151,8 @@ setGeneric("dsHasResource",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsAssignTable(con, "D", "test.CNSIM")
 #' dsDisconnect(con)
 #' }
@@ -176,8 +179,8 @@ setGeneric("dsAssignTable",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsAssignResource(con, "D", "test.CNSIM")
 #' dsDisconnect(con)
 #' }
@@ -204,8 +207,8 @@ setGeneric("dsAssignResource",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsAssignExpr(con, "C", as.symbol("c(1, 2, 3)"))
 #' dsDisconnect(con)
 #' }
@@ -231,8 +234,8 @@ setGeneric("dsAssignExpr",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsAssignTable(con, "D", "test.CNSIM")
 #' dsAggregate(con, as.symbol("meanDS(D$WEIGHT)"))
 #' dsDisconnect(con)
@@ -255,8 +258,8 @@ setGeneric("dsAggregate",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsAssignTable(con, "D", "test.CNSIM")
 #' dsListSymbols(con)
 #' dsDisconnect(con)
@@ -280,8 +283,8 @@ setGeneric("dsListSymbols",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsAssignTable(con, "D", "test.CNSIM")
 #' dsRmSymbol(con, "D")
 #' dsDisconnect(con)
@@ -291,6 +294,31 @@ setGeneric("dsListSymbols",
 setGeneric("dsRmSymbol",
            def = function(conn, symbol) standardGeneric("dsRmSymbol"))
 
+#' Get the DataSHIELD profiles
+#'
+#' Get the list of DataSHIELD profiles that have been configured on the remote data repository.
+#'
+#' @template methods
+#' @templateVar method_name dsListProfiles
+#'
+#' @param conn An object that inherits from \code{\link{DSConnection-class}}.
+#'
+#' @return A list containing the "available" character vector of profile names and the "current" profile (in case a default one was assigned).
+#'
+#' @family DSConnection generics
+#' @examples
+#' \dontrun{
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
+#' dsListProfiles(con)
+#' dsDisconnect(con)
+#' }
+#' @import methods
+#' @export
+setGeneric("dsListProfiles",
+           def = function(conn) standardGeneric("dsListProfiles"),
+           valueClass = "list")
+
 #' Get the DataSHIELD methods
 #'
 #' Get the list of DataSHIELD methods that have been configured on the remote data repository.
@@ -306,8 +334,8 @@ setGeneric("dsRmSymbol",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsListMethods(con)
 #' dsDisconnect(con)
 #' }
@@ -331,8 +359,8 @@ setGeneric("dsListMethods",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsListPackages(con)
 #' dsDisconnect(con)
 #' }
@@ -357,8 +385,8 @@ setGeneric("dsListPackages",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsListWorkspaces(con)
 #' dsDisconnect(con)
 #' }
@@ -381,8 +409,8 @@ setGeneric("dsListWorkspaces",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsSaveWorkspace(con, "foo")
 #' dsListWorkspaces(con)
 #' dsDisconnect(con)
@@ -406,8 +434,8 @@ setGeneric("dsSaveWorkspace",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsSaveWorkspace(con, "foo")
 #' dsListWorkspaces(con)
 #' dsRmWorkspace(con, "foo")
@@ -435,8 +463,8 @@ setGeneric("dsRmWorkspace",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsIsAsync(con)
 #' dsDisconnect(con)
 #' }
@@ -460,8 +488,8 @@ setGeneric("dsIsAsync",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsKeepAlive(con)
 #' dsDisconnect(con)
 #' }
@@ -484,8 +512,8 @@ setGeneric("dsKeepAlive",
 #' @family DSConnection generics
 #' @examples
 #' \dontrun{
-#' con <- dbConnect(DSOpal::Opal(), "server1",
-#'   "username", "password", "https://opal.example.org")
+#' con <- dsConnect(DSOpal::Opal(), "server1",
+#'   username = "dsuser", password = "password", url = "https://opal-demo.obiba.org")
 #' dsDisconnect(con)
 #' }
 #' @import methods
